@@ -2,32 +2,36 @@
 import logging
 from ast import literal_eval
 from pathlib import Path
-from typing import List
+from typing import List, Union
 
 from git import Repo
 
 LOGGER = logging.getLogger(__name__)
 
 
-def get_odoo_addons_in_folder(search_folder: Path) -> List[Path]:
-    """List all Valid odoo module names in the Workspace addon folder.
+def get_odoo_module_paths(search_folders: Union[List[Path], Path]) -> List[Path]:
+    """List all Valid odoo module names in one or many Odoo addons folder.
 
     Parameters
     ----------
-    search_folder : Path
-        Folder to search in.
+    search_folders : Path
+        Folder(s) to search in.
 
     Returns
     -------
     List[Path]
         List of Valid Module Folders within search_folder
     """
+    if not isinstance(search_folders, List):
+        search_folders = [search_folders]
+
     module_paths = []
-    if not search_folder.exists():
-        return
-    for folder in search_folder.iterdir():
-        if folder.is_dir() and any(folder.glob("__manifest__.py")):
-            module_paths.append(folder)
+    for folder in search_folders:
+        if not folder.exists():
+            return
+        for folder in folder.iterdir():
+            if folder.is_dir() and any(folder.glob("__manifest__.py")):
+                module_paths.append(folder)
     return module_paths
 
 
@@ -82,7 +86,7 @@ def get_depends_of_modules(addon_path: Path, in_module_paths: List[Path]) -> Lis
     List[Path]
         Union of in_module_paths and all their downstream depends.
     """
-    all_modules = get_odoo_addons_in_folder(addon_path)
+    all_modules = get_odoo_module_paths(addon_path)
     if not in_module_paths:
         return
     added = True
@@ -130,12 +134,47 @@ def get_addon_paths(
         List of valid addon Paths
     """
     odoo_addon_paths = [odoo_main_repo / "addons"]
-    if get_odoo_addons_in_folder(workspace_addon_path):
+    if get_odoo_module_paths(workspace_addon_path):
         odoo_addon_paths.append(workspace_addon_path)
-    zip_addon_repos = [f for f in zip_addon_path.iterdir() if f.is_dir() and get_odoo_addons_in_folder(f)]
+    zip_addon_repos = [f for f in zip_addon_path.iterdir() if f.is_dir() and get_odoo_module_paths(f)]
     odoo_addon_paths += zip_addon_repos
     git_thirdparty_addon_repos = [
         p for p in thirdparty_addon_path.iterdir() if p.is_dir() and not p.resolve() == zip_addon_path.resolve()
     ]
     odoo_addon_paths += git_thirdparty_addon_repos
     return odoo_addon_paths
+
+
+def _get_python_requirements_of_modules(addon_paths: List[Path], filter_module_names: List[str] = None):
+    """Install python requirements mentioned in module manifests
+
+    Parameters
+    ----------
+    addon_paths : List[Path]
+        Paths to look for addons. (same as odoo-bin)
+    filter_module_names : List[str], optional
+        Modules to look for manifests, by default all available modules
+    """
+    LOGGER.debug("Checking python requirements of Modules: %s", ", ".join(filter_module_names))
+    available_modules = get_odoo_module_paths(addon_paths)
+    available_module_names = [p.stem for p in available_modules]
+    if not filter_module_names:
+        filter_module_names = available_module_names
+    filter_module_names = [f for f in filter_module_names if f not in ["base", "web"]]
+
+    if unavailable_modules := [m for m in filter_module_names if m not in available_module_names]:
+        LOGGER.warning("Couldn't search Python reqs for unavailable Modules: %s", ", ".join(unavailable_modules))
+
+    check_modules = [mp for mp in available_modules if mp.stem in filter_module_names]
+    if not check_modules:
+        LOGGER.debug("No Modules provided to check for python Requirements")
+        return
+    python_depends = []
+    for module_path in check_modules:
+        manifest_path = module_path / "__manifest__.py"
+        LOGGER.debug("Loading Manifest: %s", manifest_path.absolute())
+        manifest = literal_eval(manifest_path.read_text())
+        if module_depends := manifest.get("external_dependencies", {}).get("python"):
+            python_depends += module_depends
+
+    return python_depends
